@@ -29,6 +29,8 @@
 
 G_BEGIN_DECLS
 
+typedef struct _GfDBusDisplayConfig GfDBusDisplayConfig;
+
 typedef struct _GfMonitorConfigManager GfMonitorConfigManager;
 typedef struct _GfMonitorConfigStore GfMonitorConfigStore;
 typedef struct _GfMonitorsConfig GfMonitorsConfig;
@@ -43,6 +45,7 @@ typedef struct _GfGpu GfGpu;
 
 typedef struct _GfCrtc GfCrtc;
 typedef struct _GfOutput GfOutput;
+typedef struct _GfOutputCtm GfOutputCtm;
 typedef struct _GfCrtcMode GfCrtcMode;
 
 G_END_DECLS
