@@ -24,6 +24,7 @@
 #define GF_SETTINGS_PRIVATE_H
 
 #include "gf-backend.h"
+#include "gf-settings.h"
 
 G_BEGIN_DECLS
 
@@ -34,8 +35,6 @@ GfSettings *gf_settings_new                       (GfBackend  *backend);
 
 void        gf_settings_post_init                 (GfSettings *settings);
 
-gint        gf_settings_get_ui_scaling_factor     (GfSettings *settings);
-
 gboolean    gf_settings_get_global_scaling_factor (GfSettings *settings,
                                                    gint       *global_scaling_factor);
 
